@@ -61,7 +61,7 @@ QHash<int,QByteArray> getRoleHash()
 FrameTableModel::FrameTableModel(
     bool id3v1, CoreTaggedFileIconProvider* colorProvider, QObject* parent)
   : QAbstractTableModel(parent), m_markedRows(0), m_changedFrames(0),
-    m_colorProvider(colorProvider), m_id3v1(id3v1)
+    m_colorProvider(colorProvider), m_id3v1(id3v1), m_emptyHeaders(false)
 {
   setObjectName(QLatin1String("FrameTableModel"));
 }
@@ -217,7 +217,13 @@ QVariant FrameTableModel::data(const QModelIndex& index, int role) const
     }
     return result;
   } else if (role == CompletionsRole) {
+#if QT_VERSION >= 0x050e00
+    const QSet<QString> completions =
+        getCompletionsForType(it->getExtendedType());
+    QStringList result(completions.constBegin(), completions.constEnd());
+#else
     QStringList result = getCompletionsForType(it->getExtendedType()).toList();
+#endif
     result.sort();
     return result;
   } else if (role == NoticeRole) {
@@ -285,7 +291,7 @@ bool FrameTableModel::setData(const QModelIndex& index,
 QVariant FrameTableModel::headerData(
     int section, Qt::Orientation orientation, int role) const
 {
-  if (role != Qt::DisplayRole)
+  if (role != Qt::DisplayRole || m_emptyHeaders)
     return QVariant();
   if (orientation == Qt::Horizontal) {
     return section == CI_Enable ? tr("Name") : tr("Data");
