@@ -636,12 +636,18 @@ void BaseMainWindowImpl::updateStatusLabel()
   if (m_statusLabel) {
     QStringList counts;
     if (m_folderCount != 0) {
+      //~ singular %n folder
+      //~ plural %n folders
       counts.append(tr("%n folders", "", m_folderCount));
     }
     if (m_fileCount != 0) {
+      //~ singular %n file
+      //~ plural %n files
       counts.append(tr("%n files", "", m_fileCount));
     }
     if (m_selectionCount != 0) {
+      //~ singular %n selected
+      //~ plural %n selected
       counts.append(tr("%n selected", "", m_selectionCount));
     }
     if (counts.isEmpty()) {
@@ -1480,7 +1486,14 @@ void BaseMainWindowImpl::renameFile()
         TaggedFileIterator::closeFileHandles(index);
       }
       QString newPath = dirName + QLatin1Char('/') + newFileName;
-      if (model->rename(index, newFileName)) {
+      bool ok = model->rename(index, newFileName);
+      if (!ok && !(index.flags() & Qt::ItemIsEditable)) {
+        // The file system model seems to be too restrictive, renaming without
+        // write permission is possible on Linux, so try again without
+        // using the model.
+        ok = QFile::rename(absFilename, newPath);
+      }
+      if (ok) {
         if (taggedFile) {
           taggedFile->updateCurrentFilename();
           if (selItems.size() == 1) {
